import {useEffect, useState} from "react";
import './GenshinDownloads.scss';
import Loading from "../../ui/Loading/Loading";
import * as url from "url";

const GenshinDownloads = () => {
    const [genshinDL, setGenshinDL] = useState<GenshinDLType[]>([]);
    const [loading, setLoading] = useState(true);
    const [outdatedCollapse, setOutdatedCollapse] = useState(true);
    const [betaCollapse, setBetaCollapse] = useState(true);

    useEffect(() => {
        // const url = 'https://baka.nix13.pw/genshin';
        const url = 'http://localhost:8099/genshin'
        fetch(url)
            .then(r => r.json())
            .then(r => setGenshinDL(r.genshin))
            .then(_ => setLoading(false));
    }, []);

    if(loading || !genshinDL) return <Loading/>;
    return (
        <div className={'GenshinDownloads'} id='GenshinDownloads'>
            <h1 className={'GenshinDownloads__Actual'}>Актуальная версия</h1>
            {genshinDL.filter(dl => !dl.outdated && !dl.beta).map(dl => (
                <div className={'GenshinDownloads__Item'} key={dl.name}>
                    <h2 className={'GenshinDownloads__Item_Title'}>{dl.name}</h2>

                    <div className="GenshinDownloads__Item_Links">
                        {dl.links.map(link => (
                            <a
                                href={link.url}
                                key={link.name}
                                className={'Button--Outline GenshinDownloads__Item_Links_Link'}
                            >
                                {link.name}
                            </a>
                        ))}
                    </div>
                </div>
            ))}

            <h1 className={`GenshinDownloads__Outdated ${outdatedCollapse && 'GenshinDownloads__Outdated--NotCollapsed'}`} onClick={() => setOutdatedCollapse(!outdatedCollapse)}>Устаревшие версии</h1>
            {!outdatedCollapse && genshinDL.filter(dl => dl.outdated && !dl.beta).map(dl => (
                <div className={'GenshinDownloads__Item'} key={dl.name}>
                    <h2 className={'GenshinDownloads__Item_Title'}>{dl.name}</h2>
                    <div className="GenshinDownloads__Item_Links">
                        {dl.links.map(link => (
                            <a
                                href={link.url}
                                key={link.name}
                                className={'Button--Outline GenshinDownloads__Item_Links_Link GenshinDownloads__Item_Links_Link--Outdated'}
                            >
                                {link.name}
                            </a>
                        ))}
                    </div>
                </div>
            ))}

            <h1 className={`GenshinDownloads__Beta ${betaCollapse && 'GenshinDownloads__Beta--NotCollapsed'}`} onClick={() => setBetaCollapse(!betaCollapse)}>Бета версии</h1>
            {!betaCollapse && genshinDL.filter(dl => dl.beta).map(dl => (
                <div className={'GenshinDownloads__Item'} key={dl.name}>
                    <h2 className={'GenshinDownloads__Item_Title'}>{dl.name}</h2>
                    <div className="GenshinDownloads__Item_Links">
                        {dl.links.map(link => (
                            <a
                                href={link.url}
                                key={link.name}
                                className={'Button--Outline GenshinDownloads__Item_Links_Link GenshinDownloads__Item_Links_Link--Beta'}
                            >
                                {link.name}
                            </a>
                        ))}
                    </div>
                </div>
            ))}
        </div>
    );
}

export default GenshinDownloads;